==> ejc-sealm-api-3.0.0-20220129.010215-38-sources.jar: com.ejianc.business.sealm/vo/YzsqSealOrderVo.java <==
package com.ejianc.business.sealm.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.List;

/**
 * @Author Chen chunlei
 * @Date 2022/1/25/025 18:45
 */
public class YzsqSealOrderVo extends BaseVO{
    private static final long serialVersionUID = 1L;

    private String workflowName; // 流程名称
    private String caseId; // 事项ID
    private String title; // 事项标题
    private String fingerNo; // 实际用印人工号

    private String sealUserName; // 实际用印人姓名
    private String formNo; // 流程单号
    private String vertifyCode; // 验证码
    private String applicantName; // 申请人姓名

    private String depName; // 部门名称
    private String description; // 用印事由
    private String phoneNumber; // 电话号码
    private String isTakeOut; // 是否外带(不传默认正常)


    private List<QjykyVO> detail;  //子表信息


    public String getWorkflowName() {
        return workflowName;
    }

    public void setWorkflowName(String workflowName) {
        this.workflowName = workflowName;
    }

    public String getCaseId() {
        return caseId;
    }

    public void setCaseId(String caseId) {
        this.caseId = caseId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getFingerNo() {
        return fingerNo;
    }

    public void setFingerNo(String fingerNo) {
        this.fingerNo = fingerNo;
    }

    public String getSealUserName() {
        return sealUserName;
    }

    public void setSealUserName(String sealUserName) {
        this.sealUserName = sealUserName;
    }

    public String getFormNo() {
        return formNo;
    }

    public void setFormNo(String formNo) {
        this.formNo = formNo;
    }

    public String getVertifyCode() {
        return vertifyCode;
    }

    public void setVertifyCode(String vertifyCode) {
        this.vertifyCode = vertifyCode;
    }

    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public String getDepName() {
        return depName;
    }

    public void setDepName(String depName) {
        this.depName = depName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public String getIsTakeOut() {
        return isTakeOut;
    }

    public void setIsTakeOut(String isTakeOut) {
        this.isTakeOut = isTakeOut;
    }

    public List<QjykyVO> getDetail() {
        return detail;
    }

    public void setDetail(List<QjykyVO> detail) {
        this.detail = detail;
    }
}

==> ejc-sealm-api-3.0.0-20220822.102301-118-sources.jar: com.ejianc.business.sealm/vo/YzsqSealOrderVo.java <==
package com.ejianc.business.sealm.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.List;

/**
 * @Author Chen chunlei
 * @Date 2022/1/25/025 18:45
 */
public class YzsqSealOrderVo extends BaseVO{
    private static final long serialVersionUID = 1L;

    private String workflowName; // 流程名称
    private String caseId; // 事项ID
    private String title; // 事项标题
    private String fingerNo; // 实际用印人工号

    private String sealUserName; // 实际用印人姓名
    private String formNo; // 流程单号
    private String vertifyCode; // 验证码
    private String applicantName; // 申请人姓名

    private String depName; // 部门名称
    private String description; // 用印事由
    private String phoneNumber; // 电话号码
    private String isTakeOut; // 是否外带(不传默认正常)


    private List<QjykyVO> details;  //子表信息


    public String getWorkflowName() {
        return workflowName;
    }

    public void setWorkflowName(String workflowName) {
        this.workflowName = workflowName;
    }

    public String getCaseId() {
        return caseId;
    }

    public void setCaseId(String caseId) {
        this.caseId = caseId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getFingerNo() {
        return fingerNo;
    }

    public void setFingerNo(String fingerNo) {
        this.fingerNo = fingerNo;
    }

    public String getSealUserName() {
        return sealUserName;
    }

    public void setSealUserName(String sealUserName) {
        this.sealUserName = sealUserName;
    }

    public String getFormNo() {
        return formNo;
    }

    public void setFormNo(String formNo) {
        this.formNo = formNo;
    }

    public String getVertifyCode() {
        return vertifyCode;
    }

    public void setVertifyCode(String vertifyCode) {
        this.vertifyCode = vertifyCode;
    }

    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public String getDepName() {
        return depName;
    }

    public void setDepName(String depName) {
        this.depName = depName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public String getIsTakeOut() {
        return isTakeOut;
    }

    public void setIsTakeOut(String isTakeOut) {
        this.isTakeOut = isTakeOut;
    }

    public List<QjykyVO> getDetails() {
        return details;
    }

    public void setDetails(List<QjykyVO> details) {
        this.details = details;
    }
}
